log-model: Logs performance of the statistical or machine learning model...

Description Usage Arguments

Description

Logs performance of the statistical or machine learning model into InfluxDb

Usage

1
2
log_model_performance(dataset, target, test, algorithm, metric, group, records,
  value)

Arguments

dataset

name of the dataset that was targed by the model, e.g. 'sessions'

target

explained variable, e.g. 'conversion rate“

test

boolean defines whether validation was done on test or training dataset

algorithm

name of the method that was used to create the model

metric

name of the model performance metric, e.g. rsquared or mape

group

group within the data if data is split into different segments

records

size of the sample that was used to estimate the model

value

value of the model performance metric on a given sample


byapparov/rmeta documentation built on May 10, 2019, 1:18 a.m.