log-task: Metadata for task execution

Description Usage Arguments Details

Description

Functions that allow to log execution of pipeline tasks

Usage

1
2
3
4
5
log_load(destination, records, increment)

read_increment(destination)

read_loads(job, destination, days = 7L)

Arguments

destination

name of the table that data is written to

records

number of records processed by the job

increment

the largest value in the increment field of the destination

job

name of the data pipeline

days

number of days from now that will be included in the extract

Details

'read_increment' -gets largest increment for the given destination

'read_loads' - reads all uploads within a given timeperiod


byapparov/rmeta documentation built on May 10, 2019, 1:18 a.m.