Learn R Programming

rmeta (version 3.0)

meta.MH: Fixed effects (Mantel-Haenszel) meta-analysis

Description

Computes the individual odds ratio or relative risk, the Mantel-Haenszel summary, and Woolf's test for heterogeneity. The print method gives the summary and test for heterogeneity; the summary method also gives all the individual odds ratios and confidence intervals.

The plot method draws a standard meta-analysis plot. The confidence interval for each study is given by a horizontal line, and the point estimate is given by a square whose height is inversely proportional to the standard error of the estimate. The summary odds ratio, if requested, is drawn as a diamond with horizontal limits at the confidence limits and width inversely proportional to its standard error.

Usage

meta.MH(ntrt, nctrl, ptrt, pctrl, conf.level=0.95,
        names=NULL, data=NULL, subset=NULL, na.action = na.fail,statistic="OR")
# S3 method for meta.MH
summary(object, conf.level=NULL, …)
# S3 method for meta.MH
plot(x, summary=TRUE, summlabel="Summary",
             conf.level=NULL, colors=meta.colors(),xlab=NULL, …)

Arguments

ntrt

Number of subjects in treated/exposed group

nctrl

Number of subjects in control group

ptrt

Number of events in treated/exposed group

pctrl

Number of events in control group

names

names or labels for studies

data

data frame to interpret variables

subset

subset of studies to include

na.action

a function which indicates what should happen when the data contain NAs. Defaults to na.fail.

statistic

"OR" for odds ratio, "RR" for relative risk

x,object

a meta.MH object

summary

Plot the summary odds ratio?

summlabel

Label for the summary odds ratio

conf.level

Coverage for confidence intervals

colors
xlab

x-axis label, default is based on statistic

…

further arguments to be passed to or from methods.

Value

An object of class meta.MH with print, plot, funnelplot and summary methods.

See Also

plot,par,meta.DSL,funnelplot

Examples

Run this code
# NOT RUN {
data(catheter)
a <- meta.MH(n.trt, n.ctrl, col.trt, col.ctrl, data=catheter,
             names=Name, subset=c(13,6,5,3,7,12,4,11,1,8,10,2))
a
summary(a)
plot(a)
d <- meta.MH(n.trt, n.ctrl, inf.trt, inf.ctrl, data=catheter,
             names=Name, subset=c(13,6,3,12,4,11,1,14,8,10,2))
d
summary(d)
## plot with par("fg")
plot(d, colors=meta.colors(NULL))
# }

Run the code above in your browser using DataLab